﻿using System;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace DisplayASimpleMapForMvc.Controllers
{
    public class IndexController : Controller
    {
        //
        // GET: /UseDraggableMarkers/

        public ActionResult Index()
        {
            Map map = new Map("Map1",
    new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
    new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));

            map.MapUnit = GeographyUnit.DecimalDegree;
            map.CurrentExtent = new RectangleShape(-155.733, 95.60, 104.42, -81.9);

            ClassBreakStyle classBreakStyle = new ClassBreakStyle("POP1990");
            classBreakStyle.BreakValueInclusion = BreakValueInclusion.IncludeValue;
            classBreakStyle.ClassBreaks.Add(new ClassBreak(500000, new AreaStyle(new GeoPen(new GeoColor(255, 0, 0, 0)), new GeoSolidBrush(new GeoColor(255, 154, 205, 50)))));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(5000000, new AreaStyle(new GeoPen(new GeoColor(255, 0, 0, 0)), new GeoSolidBrush(new GeoColor(255, 211, 217, 37)))));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(15000000, new AreaStyle(new GeoPen(new GeoColor(255, 0, 0, 0)), new GeoSolidBrush(new GeoColor(255, 230, 168, 24)))));

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(Server.MapPath("~/Data/USStates.shp"));
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(classBreakStyle);

            LayerOverlay overlay = new LayerOverlay();
            overlay.TileType = TileType.SingleTile;
            overlay.IsBaseOverlay = true;
            overlay.Layers.Add(worldLayer);

            LayerOverlay legendOverlay = new LayerOverlay();
            legendOverlay.IsBaseOverlay = false;
            legendOverlay.Layers.Add(BuildLegend());
            legendOverlay.TileType = TileType.SingleTile;
            map.CustomOverlays.Add(overlay);
            
            map.CustomOverlays.Add(legendOverlay);
            return View(map);
        }

        private LegendAdornmentLayer BuildLegend()
        {
            LegendItem title = new LegendItem();
            title.TextStyle = new TextStyle("Map Legend", new GeoFont("Arial", 10, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            LegendItem legendItem1 = new LegendItem();
            legendItem1.ImageStyle = new AreaStyle(new GeoPen(new GeoColor(255, 0, 0, 0)), new GeoSolidBrush(new GeoColor(255, 154, 205, 50)));
            legendItem1.TextStyle = new TextStyle("0 - 2500000", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            LegendItem legendItem2 = new LegendItem();
            legendItem2.ImageStyle = new AreaStyle(new GeoPen(new GeoColor(255, 0, 0, 0)), new GeoSolidBrush(new GeoColor(255, 211, 217, 37)));
            legendItem2.TextStyle = new TextStyle("2500000 - 7500000", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            LegendItem legendItem3 = new LegendItem();
            legendItem3.ImageStyle = new AreaStyle(new GeoPen(new GeoColor(255, 0, 0, 0)), new GeoSolidBrush(new GeoColor(255, 230, 168, 24)));
            legendItem3.TextStyle = new TextStyle("> 7500000", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            LegendAdornmentLayer legendLayer = new LegendAdornmentLayer();
            legendLayer.BackgroundMask = AreaStyles.CreateLinearGradientStyle(new GeoColor(255, 255, 255, 255), new GeoColor(255, 230, 230, 230), 90, GeoColor.SimpleColors.Black);
            legendLayer.LegendItems.Add(legendItem1);
            legendLayer.LegendItems.Add(legendItem2);
            legendLayer.LegendItems.Add(legendItem3);
            legendLayer.Width = 200;
            legendLayer.Height = 125;
            legendLayer.Title = title;
            legendLayer.Location = AdornmentLocation.LowerRight;

            return legendLayer;
        }
    }
}
